##############
Visualization
##############

The built-in visualization feature is experimental. Currently, users are recommended to use third-party tools such as QGIS to visualize the GEOJSON outputs.
